function [K]=cal_K_CSFEM_Q4(nSD)

%------------------------------------------------------------------------
%  Purpose:
%     Calculate the global stiffness matrix K of CSFEM using Q4 element
%
%  Synopsis:
%     [K]=cal_K_CSFEM_Q4(nSD)  
%
%  Variable Description:
%     K     : global stiffness matrix
%    nSD    : number of smoothing domains per element
%
%  Some main variables in the function
%   index   : vector containing system dofs associated with each element
%   Ke      : element stiffness matrix
%--------------------------------------------------------------------------
% Coded by Dr. Nguyen Thoi Trung (Nguyen-Thoi T or Nguyen T.T)            %
% University of Science - Vietnam National University  HCMC, Vietnam     %
% National University of Singapore (NUS)                                  %
% email: thoitrung76@gmail.com                                            %
% Last modified: December 2009                                            %
%--------------------------------------------------------------------------

% Important note: The authors decided to release the source codes free of charge with the hope that the S-FEM technique 
% can be applied to more problems and can be further developed into even more powerful methods. 
% The authors are not be able to provide any services or user-guides, but appreciate very much your feedback on errors and suggestions, 
% so that we can improve these codes/methods in the future. If the idea, method, and any part of these codes are used in anyway,
% the users are required to cite the book and the following related original papers of the authors:

% Liu GR, The Finite element method  a practical course, Elsevier (BH), UK.  2003.
% Liu, G. R. and Nguyen Thoi Trung, Smoothed Finite Element Method, CRC press, Boca Raton, USA, 2010.
% Liu GR, Dai KY, Nguyen-Thoi T (2007) A smoothed finite element method for mechanics problems. Computational Mechanics; 39: 859-877.
% Dai KY, Liu GR (2007) Free and forced vibration analysis using the smoothed finite element method (SFEM). Journal of Sound and Vibration; 301: 803-820.
% Dai KY, Liu GR, Nguyen-Thoi T (2007) An n-sided polygonal smoothed finite element method (nSFEM) for solid mechanics. Finite Elements in Analysis and Design; 43: 847?860. 
% Nguyen-Thoi T, Liu GR, Dai KY, Lam KY (2007) Selective Smoothed Finite Element Method. Tsinghua Science and Technology; 12(5): 497-508.
% Liu GR, Nguyen-Thoi T, Dai KY, Lam KY (2007) Theoretical aspects of the smoothed finite element method (SFEM). International Journal for Numerical Methods in Engineering; 71: 902-930.
% Liu GR, Nguyen-Thoi T, Nguyen-Xuan H, Dai KY, Lam KY (2009) On the essence and the evaluation of the shape functions for the smoothed finite element method (SFEM) (Letter to Editor). International Journal for Numerical Methods in Engineering; 77: 1863-1869. 
% Liu GR, Nguyen-Thoi T, Nguyen-Xuan H, Lam KY (2009) A node-based smoothed finite element method (NS-FEM) for upper bound solutions to solid mechanics problems. Computers and Structures; 87: 14-26.
%--------------------------------------------------------------------------

global sdof ndof nel nnel ele_nods gcoord matmtx

K=sparse(sdof,sdof);  % initialization of global stiffness matrix
for iel=1:nel         % loop for the total number of element        
    for i=1:nnel      % loop for 4 nodes of (iel)-th element
        nod(i)=ele_nods(iel,i);    % extract nodes for (iel)-th element
        xco(i)=gcoord(nod(i),1);   % extract x value of the node
        yco(i)=gcoord(nod(i),2);   % extract y value of the node
    end 
    Ke = cal_Ke_CSFEM_Q4(nSD,xco,yco,matmtx);  % (iel)-th element stiffness matrix             
    index = get_eledof(nod,nnel,ndof);  % extract system dofs for the element    
    K(index,index) = K(index,index) + Ke; % assemble element stiffness matrices            
end 
   