function [angle]=cal_angle_Q4(x,y)

%--------------------------------------------------------
%purpose:
% compute four angles of Q4 element
%
%Synopsis:
% [angle]=cal_angle_Q4(x,y)
%
%variable description:
% angle : vector containing values of 4 angles of Q4 element
%  x    : x coord value of element
%  y    : y coord value of element
%--------------------------------------------------------------------------
% Coded by Dr. Nguyen Thoi Trung (Nguyen-Thoi T or Nguyen T.T)            %
% University of Science - Vietnam National University  HCMC, Vietnam     %
% National University of Singapore (NUS)                                  %
% email: thoitrung76@gmail.com                                            %
% Last modified: December 2009                                            %
%--------------------------------------------------------------------------

% Important note: The authors decided to release the source codes free of charge with the hope that the S-FEM technique 
% can be applied to more problems and can be further developed into even more powerful methods. 
% The authors are not be able to provide any services or user-guides, but appreciate very much your feedback on errors and suggestions, 
% so that we can improve these codes/methods in the future. If the idea, method, and any part of these codes are used in anyway,
% the users are required to cite the book and the following related original papers of the authors:

% Liu GR, The Finite element method  a practical course, Elsevier (BH), UK.  2003.
% Liu, G. R. and Nguyen Thoi Trung, Smoothed Finite Element Method, CRC press, Boca Raton, USA, 2010.
%--------------------------------------------------------------------------

e1=sqrt((x(2)-x(4))^2+(y(2)-y(4))^2);
e2=sqrt((x(1)-x(3))^2+(y(1)-y(3))^2);

a=sqrt((x(1)-x(2))^2+(y(1)-y(2))^2);
b=sqrt((x(2)-x(3))^2+(y(2)-y(3))^2);
c=sqrt((x(3)-x(4))^2+(y(3)-y(4))^2);
d=sqrt((x(4)-x(1))^2+(y(4)-y(1))^2);

cosA1=(d^2+e2^2-c^2)/(2*d*e2);
cosA2=(a^2+e2^2-b^2)/(2*a*e2);
cosB1=(a^2+e1^2-d^2)/(2*a*e1);
cosB2=(b^2+e1^2-c^2)/(2*b*e1);
cosC1=(b^2+e2^2-a^2)/(2*b*e2);
cosC2=(c^2+e2^2-d^2)/(2*c*e2);
cosD1=(c^2+e1^2-b^2)/(2*c*e1);
cosD2=(d^2+e1^2-a^2)/(2*d*e1);

angle(1)=acos(cosA1)+acos(cosA2);
angle(2)=acos(cosB1)+acos(cosB2);
angle(3)=acos(cosC1)+acos(cosC2);
angle(4)=acos(cosD1)+acos(cosD2);