function [area_ele]=cal_area_ele(x,y)

%--------------------------------------------------------
%purpose:
%compute the area of each element
%
%Synopsis:
%[area]=cal_area(x,y)
%
%variable description:
%area - the area of each element
%x - x coord value of element
%y - y coord value of element
%--------------------------------------------------------------------------
% Coded by Dr. Nguyen Thoi Trung (Nguyen-Thoi T or Nguyen T.T)            %
% University of Science - Vietnam National University  HCMC, Vietnam     %
% National University of Singapore (NUS)                                  %
% email: thoitrung76@gmail.com                                            %
% Last modified: December 2009                                            %
%--------------------------------------------------------------------------

% Important note: The authors decided to release the source codes free of charge with the hope that the S-FEM technique 
% can be applied to more problems and can be further developed into even more powerful methods. 
% The authors are not be able to provide any services or user-guides, but appreciate very much your feedback on errors and suggestions, 
% so that we can improve these codes/methods in the future. If the idea, method, and any part of these codes are used in anyway,
% the users are required to cite the book and the following related original papers of the authors:

% Liu GR, The Finite element method  a practical course, Elsevier (BH), UK.  2003.
% Liu, G. R. and Nguyen Thoi Trung, Smoothed Finite Element Method, CRC press, Boca Raton, USA, 2010.
%--------------------------------------------------------------------------

neel=length(x);     %neel n: number   e:edge   el:element

if neel==3        
    area_ele=0.5*(x(1)*y(2)+x(2)*y(3)+x(3)*y(1)-...
        x(1)*y(3)-x(2)*y(1)-x(3)*y(2));               %area of triangle 
elseif neel==4
    dis_1=sqrt((x(3)-x(1))^2+(y(3)-y(1))^2);
    dis_2=sqrt((x(4)-x(2))^2+(y(4)-y(2))^2);
    [angle]=cal_angle_Q4(x,y);
    if angle(1)>= pi | angle(3) >= pi   
        area1=0.5*(x(1)*y(2)+x(2)*y(3)+x(3)*y(1)-...
            x(1)*y(3)-x(2)*y(1)-x(3)*y(2));          % area of 1st triangle 
        area2=0.5*(x(1)*y(3)+x(3)*y(4)+x(4)*y(1)-...
            x(1)*y(4)-x(3)*y(1)-x(4)*y(3));          % area of 2nd triangle 
        area_ele=abs(area1)+abs(area2);
    elseif angle(2) >= pi | angle(4) >= pi
        area1=0.5*(x(1)*y(2)+x(2)*y(4)+x(4)*y(1)-...
            x(1)*y(4)-x(2)*y(1)-x(4)*y(2));          % area of 1st triangle 
        area2=0.5*(x(2)*y(3)+x(3)*y(4)+x(4)*y(2)-...
            x(2)*y(4)-x(3)*y(2)-x(4)*y(3));          % area of 2nd triangle 
        area_ele=abs(area1)+abs(area2);
    elseif angle(1) < pi & angle(2) < pi & angle(3) < pi & angle(4) < pi & dis_1 <= dis_2 
        area1=0.5*(x(1)*y(2)+x(2)*y(3)+x(3)*y(1)-...
            x(1)*y(3)-x(2)*y(1)-x(3)*y(2));          % area of 1st triangle 
        area2=0.5*(x(1)*y(3)+x(3)*y(4)+x(4)*y(1)-...
            x(1)*y(4)-x(3)*y(1)-x(4)*y(3));          % area of 2nd triangle 
        area_ele=abs(area1)+abs(area2);
    elseif angle(1) < pi & angle(2) < pi & angle(3) < pi & angle(4) < pi & dis_1 > dis_2 
        area1=0.5*(x(1)*y(2)+x(2)*y(4)+x(4)*y(1)-...
            x(1)*y(4)-x(2)*y(1)-x(4)*y(2));          % area of 1st triangle 
        area2=0.5*(x(2)*y(3)+x(3)*y(4)+x(4)*y(2)-...
            x(2)*y(4)-x(3)*y(2)-x(4)*y(3));          % area of 2nd triangle 
        area_ele=abs(area1)+abs(area2);
    end
elseif neel==5    
    area1=0.5*(x(1)*y(2)+x(2)*y(3)+x(3)*y(1)-...
        x(1)*y(3)-x(2)*y(1)-x(3)*y(2));            % area of 1st triangle    
    area2=0.5*(x(1)*y(3)+x(3)*y(4)+x(4)*y(1)-...
        x(1)*y(4)-x(3)*y(1)-x(4)*y(3));            % area of 2nd triangle    
    area3=0.5*(x(1)*y(4)+x(4)*y(5)+x(5)*y(1)-...
        x(1)*y(5)-x(4)*y(1)-x(5)*y(4));            % area of 3rd triangle    
    area_ele=abs(area1)+abs(area2)+abs(area3);    
elseif neel==6    
    area1=0.5*(x(1)*y(2)+x(2)*y(3)+x(3)*y(1)-...
        x(1)*y(3)-x(2)*y(1)-x(3)*y(2));            % area of 1st triangle     
    area2=0.5*(x(1)*y(3)+x(3)*y(4)+x(4)*y(1)-...
        x(1)*y(4)-x(3)*y(1)-x(4)*y(3));            % area of 2nd triangle     
    area3=0.5*(x(1)*y(4)+x(4)*y(5)+x(5)*y(1)-...
        x(1)*y(5)-x(4)*y(1)-x(5)*y(4));            % area of 3rd triangle    
    area4=0.5*(x(1)*y(5)+x(5)*y(6)+x(6)*y(1)-...
        x(1)*y(6)-x(5)*y(1)-x(6)*y(5));            % area of 4th triangle     
    area_ele=abs(area1)+abs(area2)+abs(area3)+abs(area4);    
end

    
        
        