function [area_edge,area_T3] = cal_area_edge_T3(edge_data)

%------------------------------------------------------------------------
%  Purpose:
%     Compute the area of SD associated with edge and element areas
%
%  Synopsis:
%     [area_edge,area_T3] = cal_area_edge_T3(edge_data)  
%
%  Variable Description:
%  area_edge = vector containing the area of SD associated with edge
%   area_T3  = vector containing the area of elements
% edge_data  = matrix containing data of (ied)-th edge 
               % edge_data(ied,1): 1st node of (ied)-th edge
               % edge_data(ied,2): 2nd node of (ied)-th edge
               % edge_data(ied,3): 1st element of (ied)-th edge
               % edge_data(ied,4): 2nd element of (ied)-th edge 
               % (if edge_data(ied,4)==0 
               % => means (ied)-th edge belongs to boundary edges
%--------------------------------------------------------------------------
% Coded by Dr. Nguyen Thoi Trung (Nguyen-Thoi T or Nguyen T.T)            %
% University of Science - Vietnam National University  HCMC, Vietnam     %
% National University of Singapore (NUS)                                  %
% email: thoitrung76@gmail.com                                            %
% Last modified: December 2009                                            %
%--------------------------------------------------------------------------

% Important note: The authors decided to release the source codes free of charge with the hope that the S-FEM technique 
% can be applied to more problems and can be further developed into even more powerful methods. 
% The authors are not be able to provide any services or user-guides, but appreciate very much your feedback on errors and suggestions, 
% so that we can improve these codes/methods in the future. If the idea, method, and any part of these codes are used in anyway,
% the users are required to cite the book and the following related original papers of the authors:

% Liu GR, The Finite element method  a practical course, Elsevier (BH), UK.  2003.
% Liu, G. R. and Nguyen Thoi Trung, Smoothed Finite Element Method, CRC press, Boca Raton, USA, 2010.
% Liu GR, Dai KY, Nguyen-Thoi T (2007) A smoothed finite element method for mechanics problems. Computational Mechanics; 39: 859-877.
% Liu GR, Nguyen-Thoi T, Lam KY (2009) An edge-based smoothed finite element method (ES-FEM) for static, free and forced vibration analyses in solids. Journal of Sound and Vibration; 320: 1100-1130.
% Nguyen-Xuan H, Liu GR, Thai-Hoang C, Nguyen-Thoi T (2009) An edge-based smoothed finite element method with stabilized discrete shear gap technique for analysis of Reissner-Mindlin plates. Computer Methods in Applied Mechanics and Engineering;  199: 471-489.
% Nguyen-Xuan H, Liu GR, Nguyen-Thoi T, Nguyen-Tran C (2009) An edge-based smoothed finite element method for analysis of two-dimensional piezoelectric structures, Smart Materials and Structures 18 (6). no. 065015.
% Nguyen-Thoi T, Liu GR, Vu-Do HC, Nguyen-Xuan H (2009) An edge-based smoothed finite element method (ES-FEM) for visco-elastoplastic analyses of 2D solids using triangular mesh. Computational Mechanics; 45: 23-44.
% Nguyen-Thoi T, Liu GR, Nguyen-Xuan H (2010) An n-sided polygonal edge-based smoothed finite element method (nES-FEM) for solid mechanics. International Journal for Numerical Methods in Biomedical Engineering; doi:10.1002/cnm.1375.
%--------------------------------------------------------------------------

global nel ele_nods gcoord 

nedge = size(edge_data,1);
%Compute the area of each triangle
for iel = 1:nel
    x1 = gcoord(ele_nods(iel,1),1);
    y1 = gcoord(ele_nods(iel,1),2);
    x2 = gcoord(ele_nods(iel,2),1);
    y2 = gcoord(ele_nods(iel,2),2);
    x3 = gcoord(ele_nods(iel,3),1);
    y3 = gcoord(ele_nods(iel,3),2);
    area_T3(iel) = 0.5*(x1*y2+x2*y3+x3*y1-x1*y3-x2*y1-x3*y2); %area of triangula;
end

%Compute the integration domain of each edge
area_edge = zeros(size(edge_data,1),1);
for ied=1:nedge
    if edge_data(ied,4)==0        
        area_edge(ied) = area_T3(edge_data(ied,3))/3;        
    else        
        area_edge(ied) = area_T3(edge_data(ied,3))/3 + area_T3(edge_data(ied,4))/3;                       
    end           
end
return
