function [area_nod] = cal_area_nod_Q4

%------------------------------------------------------------------------
%  Purpose:
%     Compute the area of SD associated with node and element areas
%
%  Synopsis:
%     [area_nod] = cal_area_nod_Q4  
%
%  Variable Description:
%   area_nod : vector containing the area of SD associated with node
%   area_Q4  : vector containing the area of elements
%--------------------------------------------------------------------------
% Coded by Dr. Nguyen Thoi Trung (Nguyen-Thoi T or Nguyen T.T)            %
% University of Science - Vietnam National University  HCMC, Vietnam     %
% National University of Singapore (NUS)                                  %
% email: thoitrung76@gmail.com                                            %
% Last modified: December 2009                                            %
%--------------------------------------------------------------------------

% Important note: The authors decided to release the source codes free of charge with the hope that the S-FEM technique 
% can be applied to more problems and can be further developed into even more powerful methods. 
% The authors are not be able to provide any services or user-guides, but appreciate very much your feedback on errors and suggestions, 
% so that we can improve these codes/methods in the future. If the idea, method, and any part of these codes are used in anyway,
% the users are required to cite the book and the following related original papers of the authors:

% Liu GR, The Finite element method  a practical course, Elsevier (BH), UK.  2003.
% Liu, G. R. and Nguyen Thoi Trung, Smoothed Finite Element Method, CRC press, Boca Raton, USA, 2010.
% Liu GR, Dai KY, Nguyen-Thoi T (2007) A smoothed finite element method for mechanics problems. Computational Mechanics; 39: 859-877.
% Dai KY, Liu GR (2007) Free and forced vibration analysis using the smoothed finite element method (SFEM). Journal of Sound and Vibration; 301: 803-820.
% Dai KY, Liu GR, Nguyen-Thoi T (2007) An n-sided polygonal smoothed finite element method (nSFEM) for solid mechanics. Finite Elements in Analysis and Design; 43: 847?860. 
% Nguyen-Thoi T, Liu GR, Dai KY, Lam KY (2007) Selective Smoothed Finite Element Method. Tsinghua Science and Technology; 12(5): 497-508.
% Liu GR, Nguyen-Thoi T, Dai KY, Lam KY (2007) Theoretical aspects of the smoothed finite element method (SFEM). International Journal for Numerical Methods in Engineering; 71: 902-930.
% Liu GR, Nguyen-Thoi T, Nguyen-Xuan H, Dai KY, Lam KY (2009) On the essence and the evaluation of the shape functions for the smoothed finite element method (SFEM) (Letter to Editor). International Journal for Numerical Methods in Engineering; 77: 1863-1869. 
%--------------------------------------------------------------------------

global gcoord nel nnode ele_nods

%Compute the area of each quadrilateral
for iel = 1:nel    
    x(1) = gcoord(ele_nods(iel,1),1);
    y(1) = gcoord(ele_nods(iel,1),2);
    x(2) = gcoord(ele_nods(iel,2),1);
    y(2) = gcoord(ele_nods(iel,2),2);
    x(3) = gcoord(ele_nods(iel,3),1);
    y(3) = gcoord(ele_nods(iel,3),2);
    x(4) = gcoord(ele_nods(iel,4),1);
    y(4) = gcoord(ele_nods(iel,4),2);    
    %S=cal_area(x,y);
    %area_Q4(iel)=S;    
    xcent(iel)=sum(x)/4;
    ycent(iel)=sum(y)/4;
end

%Compute the integration domain of each node
area_nod = zeros(nnode,1);
for ino=1:nnode
    for iel = 1:nel
        k=1;  
        while k<=4
            if find(ino==ele_nods(iel,k))> 0.5
                x(1) = gcoord(ino,1);
                y(1) = gcoord(ino,2);
                if k==4 
                    x(2) = 1/2*(gcoord(ele_nods(iel,k),1)+gcoord(ele_nods(iel,1),1));
                    y(2) = 1/2*(gcoord(ele_nods(iel,k),2)+gcoord(ele_nods(iel,1),2));
                    x(3) = xcent(iel);
                    y(3) = ycent(iel);
                    x(4) = 1/2*(gcoord(ele_nods(iel,k),1)+gcoord(ele_nods(iel,3),1));
                    y(4) = 1/2*(gcoord(ele_nods(iel,k),2)+gcoord(ele_nods(iel,3),2));
                elseif k==1
                    x(2) = 1/2*(gcoord(ele_nods(iel,k),1)+gcoord(ele_nods(iel,2),1));
                    y(2) = 1/2*(gcoord(ele_nods(iel,k),2)+gcoord(ele_nods(iel,2),2));
                    x(3) = xcent(iel);
                    y(3) = ycent(iel);
                    x(4) = 1/2*(gcoord(ele_nods(iel,k),1)+gcoord(ele_nods(iel,4),1));
                    y(4) = 1/2*(gcoord(ele_nods(iel,k),2)+gcoord(ele_nods(iel,4),2));
                else
                    x(2) = 1/2*(gcoord(ele_nods(iel,k),1)+gcoord(ele_nods(iel,k+1),1));
                    y(2) = 1/2*(gcoord(ele_nods(iel,k),2)+gcoord(ele_nods(iel,k+1),2));
                    x(3) = xcent(iel);
                    y(3) = ycent(iel);
                    x(4) = 1/2*(gcoord(ele_nods(iel,k),1)+gcoord(ele_nods(iel,k-1),1));
                    y(4) = 1/2*(gcoord(ele_nods(iel,k),2)+gcoord(ele_nods(iel,k-1),2));
                end
                area_nod(ino) = area_nod(ino) + cal_area(x,y);  
                break;
            else  
                k=k+1;            
            end
        end
    end
end

return
