function [ledge]=cal_ledge(x,y)

%--------------------------------------------------------
%purpose:
%compute the length of edges of the element
%
%Synopsis:
%[ledge]=cal_ledge(x,y)
%
%variable description:
%   ledge   - the length of each side of the element
%   x       - x coord value of element
%   y       - y coord value of element
%--------------------------------------------------------

% Important note: The authors decided to release the source codes free of charge with the hope that the S-FEM technique 
% can be applied to more problems and can be further developed into even more powerful methods. 
% The authors are not be able to provide any services or user-guides, but appreciate very much your feedback on errors and suggestions, 
% so that we can improve these codes/methods in the future. If the idea, method, and any part of these codes are used in anyway,
% the users are required to cite the book and the following related original papers of the authors:

% Liu GR, The Finite element method  a practical course, Elsevier (BH), UK.  2003.
% Liu, G. R. and Nguyen Thoi Trung, Smoothed Finite Element Method, CRC press, Boca Raton, USA, 2010.
% Liu GR, Nguyen-Thoi T, Lam KY (2009) An edge-based smoothed finite element method (ES-FEM) for static, free and forced vibration analyses in solids. Journal of Sound and Vibration; 320: 1100-1130.
% Nguyen-Xuan H, Liu GR, Thai-Hoang C, Nguyen-Thoi T (2009) An edge-based smoothed finite element method with stabilized discrete shear gap technique for analysis of Reissner-Mindlin plates. Computer Methods in Applied Mechanics and Engineering;  199: 471-489.
% Nguyen-Xuan H, Liu GR, Nguyen-Thoi T, Nguyen-Tran C (2009) An edge-based smoothed finite element method for analysis of two-dimensional piezoelectric structures, Smart Materials and Structures 18 (6). no. 065015.
% Nguyen-Thoi T, Liu GR, Vu-Do HC, Nguyen-Xuan H (2009) An edge-based smoothed finite element method (ES-FEM) for visco-elastoplastic analyses of 2D solids using triangular mesh. Computational Mechanics; 45: 23-44.
% Nguyen-Thoi T, Liu GR, Nguyen-Xuan H (2010) An n-sided polygonal edge-based smoothed finite element method (nES-FEM) for solid mechanics. International Journal for Numerical Methods in Biomedical Engineering; doi:10.1002/cnm.1375.
%--------------------------------------------------------------------------

neel=length(x);     %nsel n: number   e:edge   el:element

for ie=1:neel    
    if ie==neel
        ledge(neel)=sqrt((x(neel)-x(1))^2+(y(neel)-y(1))^2);               
    else
        ledge(ie)=sqrt((x(ie)-x(ie+1))^2+(y(ie)-y(ie+1))^2);        
    end
end