function  [nx,ny]=cal_nx_ny(x,y,ledge)

%--------------------------------------------------------
%purpose:
% compute the outside normal vector of edges of the element
%
%Synopsis:
%[nx,ny]=cal_nx_ny(x,y,ledge)
%
%variable description:
% nx    - x direction normal of edge
% ny    - y direction normal of edge
% x     - x coord value of element
% y     - y coord value of element
% ledge - the length of each edge of the element
%--------------------------------------------------------------------------
% Coded by Dr. Nguyen Thoi Trung (Nguyen-Thoi T or Nguyen T.T)            %
% University of Science - Vietnam National University  HCMC, Vietnam     %
% National University of Singapore (NUS)                                  %
% email: thoitrung76@gmail.com                                            %
% Last modified: December 2009                                            %
%--------------------------------------------------------------------------

% Important note: The authors decided to release the source codes free of charge with the hope that the S-FEM technique 
% can be applied to more problems and can be further developed into even more powerful methods. 
% The authors are not be able to provide any services or user-guides, but appreciate very much your feedback on errors and suggestions, 
% so that we can improve these codes/methods in the future. If the idea, method, and any part of these codes are used in anyway,
% the users are required to cite the book and the following related original papers of the authors:

% Liu GR, The Finite element method  a practical course, Elsevier (BH), UK.  2003.
% Liu, G. R. and Nguyen Thoi Trung, Smoothed Finite Element Method, CRC press, Boca Raton, USA, 2010.
%--------------------------------------------------------------------------

neel=length(x);     %neel n: number   e:side   el:element

for ie=1:neel    
    if ie==neel
        nx(neel)=(1/2)*(y(1)-y(neel))/(ledge(neel)/2) ;  % x direction normal of nsel th side
        ny(neel)=-(1/2)*(x(1)-x(neel))/(ledge(neel)/2);  % y direction normal of nsel th side
    else
        nx(ie)=(1/2)*(y(ie+1)-y(ie))/(ledge(ie)/2)    ;  % x direction normal of ie th side
        ny(ie)=-(1/2)*(x(ie+1)-x(ie))/(ledge(ie)/2)   ;  % y direction normal of ie th side
    end
end
