function [stress_nod]=cal_stress_nod_NSFEM_Q4(nod_adjele,disp,area_nod)                               

%------------------------------------------------------------------------
%  Purpose:
%     Calculate stresses of all nodes in NSFEM-Q4   
%
%  Synopsis:
%     [stress_nod]=cal_stress_nod_NSFEM_Q4(nod_adjele,disp,area_nod)  
%
%  Variable Description:
%   stress_nod = matrix containing stresses of nodes
%   nod_adjele = matrix containing adjacent elements of each node
%   disp       = system nodal displacement vector
%   area_nod   = vector containing the area of SD associated with node
%
%  Some main variables in the function:
%   B_ino   = strain-displacement matrix of (ino)-th smoothing domain (SD)
%   nodB    = nodes contributing (ino)-th smoothing domain
%   index   = vector containing system dofs associated with each SD
%   disp_ino= displacement vector of nodes contributing (ino)-th SD
% strain_ino= strain vector of (ino)-th SD
% stress_ino= stress vector of (ino)-th SD
%--------------------------------------------------------------------------
% Coded by Dr. Nguyen Thoi Trung (Nguyen-Thoi T or Nguyen T.T)            %
% University of Science - Vietnam National University  HCMC, Vietnam     %
% National University of Singapore (NUS)                                  %
% email: thoitrung76@gmail.com                                            %
% Last modified: December 2009                                            %
%--------------------------------------------------------------------------

% Important note: The authors decided to release the source codes free of charge with the hope that the S-FEM technique 
% can be applied to more problems and can be further developed into even more powerful methods. 
% The authors are not be able to provide any services or user-guides, but appreciate very much your feedback on errors and suggestions, 
% so that we can improve these codes/methods in the future. If the idea, method, and any part of these codes are used in anyway,
% the users are required to cite the book and the following related original papers of the authors:

% Liu GR, The Finite element method  a practical course, Elsevier (BH), UK.  2003.
% Liu, G. R. and Nguyen Thoi Trung, Smoothed Finite Element Method, CRC press, Boca Raton, USA, 2010.
% Liu GR, Nguyen-Thoi T, Nguyen-Xuan H, Lam KY (2009) A node-based smoothed finite element method (NS-FEM) for upper bound solutions to solid mechanics problems. Computers and Structures; 87: 14-26.
% Nguyen-Thoi T, Liu GR, Nguyen-Xuan H (2009) Additional properties of the node-based smoothed finite element method (NS-FEM) for solid mechanics problems. International Journal of Computational Methods, 6(4): 633-666.
% Nguyen-Thoi T, Liu GR, Nguyen-Xuan H, Nguyen-Tran C (2010) Adaptive analysis using the node-based smoothed finite element method (NS-FEM). International Journal for Numerical Methods in Biomedical Engineering; in press, doi: 10.1002/cnm.1291.
%--------------------------------------------------------------------------

global nnode nel nnel ndof matmtx

stress_nod=zeros(3,nnode);
for ino = 1:nnode        %loop for the total number of node
    %----------------------------------------------------------------------
    % compute the strain-displacement matrix of (ino)-th SD
    %----------------------------------------------------------------------
    [nodB,B_ino] = get_Bmat_NSFEM_Q4(ino,nod_adjele{ino},area_nod(ino));     
    index=get_eledof(nodB,length(nodB),ndof);    % extract system dofs for (ino)-th SD
    for i=1:length(index)
        disp_ino(i)=disp(index(i));     % extract displacements of (ino)-th SD
    end    
    strain_ino=B_ino*disp_ino';         % strain vector of (ino)-th SD
    stress_ino=matmtx*strain_ino;       % stress vector of (ino)-th SD
    stress_nod(:,ino)=stress_ino(:);    % save stress vector of (ino)-th SD into matrix containing stresses of all nodes  
    clear B_ino nodB index disp_ino strain_ino stress_ino  
end    