function [stressVM_nod]=cal_stress_vonmises(stress_nod)

%------------------------------------------------------------------------
%  Purpose:
%    Compute the stress von-Mises of all nodes in the problem domain
%
%  Synopsis:
%     [stressVM_nod]=cal_stress_vonmises(stress_nod)
%
%  Variable Description:
%   stressVM_nod = matrix containing stress von-mises of nodes 
%   stress_nod   = matrix containing stresses of nodes
%--------------------------------------------------------------------------
% Coded by Dr. Nguyen Thoi Trung (Nguyen-Thoi T or Nguyen T.T)            %
% University of Science - Vietnam National University  HCMC, Vietnam     %
% National University of Singapore (NUS) (2005-2010)                      %
% email: thoitrung76@gmail.com                                            %
% Last modified: December 2009                                            %
%--------------------------------------------------------------------------

% Important note: The authors decided to release the source codes free of charge with the hope that the S-FEM technique 
% can be applied to more problems and can be further developed into even more powerful methods. 
% The authors are not be able to provide any services or user-guides, but appreciate very much your feedback on errors and suggestions, 
% so that we can improve these codes/methods in the future. If the idea, method, and any part of these codes are used in anyway,
% the users are required to cite the book and the following related original papers of the authors:

% Liu GR, The Finite element method  a practical course, Elsevier (BH), UK.  2003.
% Liu, G. R. and Nguyen Thoi Trung, Smoothed Finite Element Method, CRC press, Boca Raton, USA, 2010.
%--------------------------------------------------------------------------

global nnode ele_nods nel nnel

if nnel==3
    for iel=1:nel   
        nod=ele_nods(iel,:);
        stress_sub1(:,:,iel)=[stress_nod(:,nod(1)) stress_nod(:,nod(2)) stress_nod(:,nod(3))];
    end         
elseif nnel==4
    for iel=1:nel   
        nod=ele_nods(iel,:);
        stress_sub1(:,:,iel)=[stress_nod(:,nod(1)) stress_nod(:,nod(2)) stress_nod(:,nod(3)) stress_nod(:,nod(4))];
    end    % end of loop for the total number of elements
end

if nnel==3 
    stress_sub=[mean(stress_sub1(:,:,:),2) mean(stress_sub1(:,:,:),2) mean(stress_sub1(:,:,:),2)];
else
    stress_sub=[mean(stress_sub1(:,:,:),2) mean(stress_sub1(:,:,:),2) mean(stress_sub1(:,:,:),2) mean(stress_sub1(:,:,:),2)];
end
stressVM_nod = zeros(1,nnode);
compt = zeros(nnode,1);
for i=1:nel
    for j=1:nnel
        sigVM = sqrt((stress_sub(1,j,i) + stress_sub(2,j,i))^2 - 3*(stress_sub(1,j,i)*stress_sub(2,j,i) - stress_sub(3,j,i)^2));
        stressVM_nod(ele_nods(i,j)) = stressVM_nod(ele_nods(i,j)) + sigVM;
        compt(ele_nods(i,j)) = compt(ele_nods(i,j))+1;
    end
end
for i=1:nnode
    stressVM_nod(i) = stressVM_nod(i)/compt(i);
end
