function [gcoord]=create_node_platehole(nx,ny,Ra,A)

%------------------------------------------------------------------------
%  Purpose:
%     Create coordinates of nodes of platehole problem
%
%  Synopsis:
%     [gcoord]=create_node_platehole(nx,ny,Ra,A)
%
%  Variable Description:
%   gcoord     = matrix containing coordinate values of each node
%   nx         = number of element in x-axis
%   ny         = number of element in y-axis
%   Ra         = inner radius of hole
%   A          = outer boundary dimension of plate  
%--------------------------------------------------------------------------
% Coded by Dr. Nguyen Thoi Trung (Nguyen-Thoi T or Nguyen T.T)            %
% University of Science - Vietnam National University  HCMC, Vietnam     %
% National University of Singapore (NUS)                                  %
% email: thoitrung76@gmail.com                                            %
% Last modified: December 2009                                            %
%--------------------------------------------------------------------------

dd=0.25;        % concentration weight! =0: even distribution!
air=0.0;

if (mod(nx,2)==1)
   'NX must be even ...!'
   pause
end

ang=pi/(2*nx);
nk=ny+ny*(ny-1)*dd/2;

nn=0;
for ip=1:nx+1   
   angi=pi/2-(ip-1)*ang;
   xi=Ra*cos(angi);  yi=Ra*sin(angi);
   if (ip<=nx/2+1)
      ye=A;  xe=ye/tan(angi);
   else
      xe=A;  ye=xe*tan(angi);
   end   
   for iq=1:ny+1
      nn=nn+1;      
      if (iq==1)
         dx=0; dy=0;
      else
       dx=(1+(ny-iq+1)*dd)*(xe-xi)/nk+dx;
       dy=(1+(ny-iq+1)*dd)*(ye-yi)/nk+dy;
      end
       gcoord(nn,1)=xe-dx;
       gcoord(nn,2)=ye-dy;    
   end
end
      