function [point2,weight2]=get_Gauss_Q4(nglx,ngly)

%-------------------------------------------------------------------
%  Purpose:
%     Get the integration points and weighting coefficients
%     of Gauss-Legendre quadrature for two-dimensional integration
%
%  Synopsis:
%     [point2,weight2]=get_Gauss_Q4(nglx,ngly) 
%
%  Variable Description:
%     nglx - number of integration points in the x-axis
%     ngly - number of integration points in the y-axis
%     point2 - vector containing integration points   
%     weight2 - vector containing weighting coefficients 
%--------------------------------------------------------------------------
% Coded by Dr. Nguyen Thoi Trung (Nguyen-Thoi T or Nguyen T.T)            %
% University of Science - Vietnam National University  HCMC, Vietnam     %
% National University of Singapore (NUS)                                  %
% email: thoitrung76@gmail.com                                            %
% Last modified: December 2009                                            %
%--------------------------------------------------------------------------

% Important note: The authors decided to release the source codes free of charge with the hope that the S-FEM technique 
% can be applied to more problems and can be further developed into even more powerful methods. 
% The authors are not be able to provide any services or user-guides, but appreciate very much your feedback on errors and suggestions, 
% so that we can improve these codes/methods in the future. If the idea, method, and any part of these codes are used in anyway,
% the users are required to cite the book and the following related original papers of the authors:

% Liu GR, The Finite element method  a practical course, Elsevier (BH), UK.  2003.
% Liu, G. R. and Nguyen Thoi Trung, Smoothed Finite Element Method, CRC press, Boca Raton, USA, 2010.
%--------------------------------------------------------------------------

%  determine the largest one between nglx and ngly

   if nglx > ngly
      ngl=nglx;
   else
      ngl=ngly;
   end

%  initialization

   point2=zeros(ngl,2);
   weight2=zeros(ngl,2);

%  find corresponding integration points and weights

 [pointx,weightx]=get_Gauss_1D(nglx);     % quadrature rule for x-axis
 [pointy,weighty]=get_Gauss_1D(ngly);     % quadrature rule for y-axis

%  quadrature for two-dimensional quadrilateral elements

 for intx=1:nglx                     % quadrature in x-axis
   point2(intx,1)=pointx(intx);
   weight2(intx,1)=weightx(intx);
 end

 for inty=1:ngly                     % quadrature in y-axis
   point2(inty,2)=pointy(inty);
   weight2(inty,2)=weighty(inty);
 end
  
