function [dNdx,dNdy]=get_dNdx_2D(nnel,dNdr,dNds,invjacob)

%------------------------------------------------------------------------
%  Purpose:
%     determine derivatives of 2-D isoparametric shape functions with 
%     respect to physical coordinate system
%
%  Synopsis:
%     [dNdx,dNdy]=get_dNdx_2D(nnel,dNdr,dNds,invjacob)  
%
%  Variable Description:
%     dNdx - derivative of shape function w.r.t. physical coordinate x
%     dNdy - derivative of shape function w.r.t. physical coordinate y
%     nnel - number of nodes per element   
%     dNdr - derivative of shape functions w.r.t. natural coordinate r
%     dNds - derivative of shape functions w.r.t. natural coordinate s
%     invjacob - inverse of 2-D Jacobian matrix
%--------------------------------------------------------------------------
% Coded by Dr. Nguyen Thoi Trung (Nguyen-Thoi T or Nguyen T.T)            %
% University of Science - Vietnam National University  HCMC, Vietnam     %
% National University of Singapore (NUS)                                  %
% email: thoitrung76@gmail.com                                            %
% Last modified: December 2009                                            %
%--------------------------------------------------------------------------

% Important note: The authors decided to release the source codes free of charge with the hope that the S-FEM technique 
% can be applied to more problems and can be further developed into even more powerful methods. 
% The authors are not be able to provide any services or user-guides, but appreciate very much your feedback on errors and suggestions, 
% so that we can improve these codes/methods in the future. If the idea, method, and any part of these codes are used in anyway,
% the users are required to cite the book and the following related original papers of the authors:

% Liu GR, The Finite element method  a practical course, Elsevier (BH), UK.  2003.
% Liu, G. R. and Nguyen Thoi Trung, Smoothed Finite Element Method, CRC press, Boca Raton, USA, 2010.
%--------------------------------------------------------------------------

 for i=1:nnel
 dNdx(i)=invjacob(1,1)*dNdr(i)+invjacob(1,2)*dNds(i);
 dNdy(i)=invjacob(2,1)*dNdr(i)+invjacob(2,2)*dNds(i);
 end
