function [edge_data,ele_edges]=get_edge_data

%------------------------------------------------------------------------
%  Purpose:
%     find data base for all of edges
%
%  Synopsis:
%     [edge_data,ele_edges]=get_edge_data  
%
%  Variable Description:
%   edge_data  = matrix containing data of (ied)-th edge 
               % edge_data(ied,1): 1st node of (ied)-th edge
               % edge_data(ied,2): 2nd node of (ied)-th edge
               % edge_data(ied,3): 1st element of (ied)-th edge
               % edge_data(ied,4): 2nd element of (ied)-th edge 
               % (if edge_data(ied,4)==0 
               % => means (ied)-th edge belongs to boundary edges
%   ele_edgs   = matrix containing edges of each element
               % ele_edges(iel,1): 1st edge of iel-th element
               % ele_edges(iel,2): 2nd edge of iel-th element
               % ele_edges(iel,3): 3rd edge of iel-th element
%--------------------------------------------------------------------------
% Coded by Dr. Nguyen Thoi Trung (Nguyen-Thoi T or Nguyen T.T)            %
% University of Science - Vietnam National University  HCMC, Vietnam     %
% National University of Singapore (NUS)                                  %
% email: thoitrung76@gmail.com                                            %
% Last modified: December 2009                                            %
%--------------------------------------------------------------------------

% Important note: The authors decided to release the source codes free of charge with the hope that the S-FEM technique 
% can be applied to more problems and can be further developed into even more powerful methods. 
% The authors are not be able to provide any services or user-guides, but appreciate very much your feedback on errors and suggestions, 
% so that we can improve these codes/methods in the future. If the idea, method, and any part of these codes are used in anyway,
% the users are required to cite the book and the following related original papers of the authors:

% Liu GR, The Finite element method  a practical course, Elsevier (BH), UK.  2003.
% Liu, G. R. and Nguyen Thoi Trung, Smoothed Finite Element Method, CRC press, Boca Raton, USA, 2010.
% Liu GR, Nguyen-Thoi T, Lam KY (2009) An edge-based smoothed finite element method (ES-FEM) for static, free and forced vibration analyses in solids. Journal of Sound and Vibration; 320: 1100-1130.
% Nguyen-Xuan H, Liu GR, Thai-Hoang C, Nguyen-Thoi T (2009) An edge-based smoothed finite element method with stabilized discrete shear gap technique for analysis of Reissner-Mindlin plates. Computer Methods in Applied Mechanics and Engineering;  199: 471-489.
% Nguyen-Xuan H, Liu GR, Nguyen-Thoi T, Nguyen-Tran C (2009) An edge-based smoothed finite element method for analysis of two-dimensional piezoelectric structures, Smart Materials and Structures 18 (6). no. 065015.
% Nguyen-Thoi T, Liu GR, Vu-Do HC, Nguyen-Xuan H (2009) An edge-based smoothed finite element method (ES-FEM) for visco-elastoplastic analyses of 2D solids using triangular mesh. Computational Mechanics; 45: 23-44.
% Nguyen-Thoi T, Liu GR, Nguyen-Xuan H (2010) An n-sided polygonal edge-based smoothed finite element method (nES-FEM) for solid mechanics. International Journal for Numerical Methods in Biomedical Engineering; doi:10.1002/cnm.1375.
%--------------------------------------------------------------------------

global ele_nods nel

edge_data=[];  % edge_data(ied,1): 1st node of ied-th edge
               % edge_data(ied,2): 2rd node of ied-th edge
               % edge_data(ied,3): 1st element of ied-th edge
               % edge_data(ied,4): 2rd element of ied-th edge 
               % (if edge_data(ied,4)==0 
               % => means ied-th edge belongs to boundary edges
edge_data=[edge_data; ele_nods(1,1) ele_nods(1,2) 1 0; ele_nods(1,2) ele_nods(1,3) 1 0; ...
            ele_nods(1,1) ele_nods(1,3) 1 0;]; % set ut the edge_data for 1st edge  

ele_edges=zeros(size(ele_nods,1),3); % ele_edges(iel,1): 1st edge of iel-th element
                                     % ele_edges(iel,2): 2nd edge of iel-th element
                                     % ele_edges(iel,3): 3rd edge of iel-th element
ele_edges(1,1:3)=1:3;                % set up the ele_edges for 1st element
for iel=2:nel     % loop from 2nd element to the last element 
    for ied=1:3   % loop for 3 edges of triangular elements
        n1=ied;  n2=(mod(ied,3)+1);  % 1st node and 2nd node of (ied)-th edge    
        flag=0;   % flag = 0:  m-th edge is new, need to be added into edge_data and ele_edges
                  % flag = 1:  the 2nd element of m-th edge was updated in edge_data and ele_edges 
        for m=1:size(edge_data,1)
            % check the edge 'n1-n2' (or 'n2-n1') of (iel)-th element belongs to m-th edge or not ??
            % if 'yes' => set up: edge_data(m,4)=iel and ele_edges(iel,n1)=m and flag=1
            % if 'no' => keep flag=0 
            if (ele_nods(iel,n1)==edge_data(m,1) & ele_nods(iel,n2)==edge_data(m,2)) | ...
                    (ele_nods(iel,n2)==edge_data(m,1) & ele_nods(iel,n1)==edge_data(m,2))
                flag=1;
                edge_data(m,4)=iel;
                ele_edges(iel,n1)=m;
                break; 
            end                        
        end
        if flag==0  % in case 'no' => add new edge 'n1-n2' into edge_data and ele_edges
            edge_data=[edge_data; ele_nods(iel,n1) ele_nods(iel,n2) iel 0;]; 
            ele_edges(iel,n1)=size(edge_data,1);
        end            
    end
end