function [nod_adjedg]=get_nod_adjedg(edge_data)

%------------------------------------------------------------------------
%  Purpose:
%     find adjacent edges of each node
%
%  Synopsis:
%     [nod_adjedg]=get_nod_adjedg(edge_data)  
%
%  Variable Description:
%    nod_adjedg - matrix containing adjacent edges of each node
%    edge_data  = matrix containing data of (ied)-th edge 
               % edge_data(ied,1): 1st node of (ied)-th edge
               % edge_data(ied,2): 2nd node of (ied)-th edge
               % edge_data(ied,3): 1st element of (ied)-th edge
               % edge_data(ied,4): 2nd element of (ied)-th edge 
               % (if edge_data(ied,4)==0 
               % => means (ied)-th edge belongs to boundary edges
%--------------------------------------------------------------------------
% Coded by Dr. Nguyen Thoi Trung (Nguyen-Thoi T or Nguyen T.T)            %
% University of Science - Vietnam National University  HCMC, Vietnam     %
% National University of Singapore (NUS)                                  %
% email: thoitrung76@gmail.com                                            %
% Last modified: December 2009                                            %
%--------------------------------------------------------------------------

% Important note: The authors decided to release the source codes free of charge with the hope that the S-FEM technique 
% can be applied to more problems and can be further developed into even more powerful methods. 
% The authors are not be able to provide any services or user-guides, but appreciate very much your feedback on errors and suggestions, 
% so that we can improve these codes/methods in the future. If the idea, method, and any part of these codes are used in anyway,
% the users are required to cite the book and the following related original papers of the authors:

% Liu GR, The Finite element method  a practical course, Elsevier (BH), UK.  2003.
% Liu, G. R. and Nguyen Thoi Trung, Smoothed Finite Element Method, CRC press, Boca Raton, USA, 2010.
% Liu GR, Nguyen-Thoi T, Lam KY (2009) An edge-based smoothed finite element method (ES-FEM) for static, free and forced vibration analyses in solids. Journal of Sound and Vibration; 320: 1100-1130.
% Nguyen-Xuan H, Liu GR, Thai-Hoang C, Nguyen-Thoi T (2009) An edge-based smoothed finite element method with stabilized discrete shear gap technique for analysis of Reissner-Mindlin plates. Computer Methods in Applied Mechanics and Engineering;  199: 471-489.
% Nguyen-Xuan H, Liu GR, Nguyen-Thoi T, Nguyen-Tran C (2009) An edge-based smoothed finite element method for analysis of two-dimensional piezoelectric structures, Smart Materials and Structures 18 (6). no. 065015.
% Nguyen-Thoi T, Liu GR, Vu-Do HC, Nguyen-Xuan H (2009) An edge-based smoothed finite element method (ES-FEM) for visco-elastoplastic analyses of 2D solids using triangular mesh. Computational Mechanics; 45: 23-44.
% Nguyen-Thoi T, Liu GR, Nguyen-Xuan H (2010) An n-sided polygonal edge-based smoothed finite element method (nES-FEM) for solid mechanics. International Journal for Numerical Methods in Biomedical Engineering; doi:10.1002/cnm.1375.
%--------------------------------------------------------------------------

global nnode

nedge=size(edge_data,1);   % total number of edges     
nod_adjedg = cell(nnode,1);
for ino=1:nnode    % loop for all nodes 
    ind=0;
    for ied=1:nedge  % loop for all edges
        if (find(ino==edge_data(ied,1:2)))>=1  
            ind = ind+1;
            nod_adjedg{ino}(ind) = ied; 
        end
    end 
end
