function [shapeT3,dhdrT3,dhdsT3]=get_shape_T3(psi,eta)

%------------------------------------------------------------------------
%  Purpose:
%     compute isoparametric T3 triangular shape functions
%     and their derivatves at the selected (integration) point
%     in terms of the natural coordinate 
%
%  Synopsis:
%     [shapeT3,dhdrT3,dhdsT3]=get_shape_T3(psi,eta)  
%
%  Variable Description:
%     shapeT3 - shape functions for nnel-node triangular element
%     dhdrT3  - derivatives of the shape functions w.r.t. r
%     dhdsT3  - derivatives of the shape functions w.r.t. s
%     psi - r coordinate value of the selected point   
%     eta - s coordinate value of the selected point
%------------------------------------------------------------------------
% 1st node at (0,0), 2nd node at (1,0), 3rd node at (0,1)
% shape functions
%--------------------------------------------------------------------------
% Coded by Dr. Nguyen Thoi Trung (Nguyen-Thoi T or Nguyen T.T)            %
% University of Science - Vietnam National University  HCMC, Vietnam     %
% National University of Singapore (NUS)                                  %
% email: thoitrung76@gmail.com                                            %
% Last modified: December 2009                                            %
%--------------------------------------------------------------------------

% Important note: The authors decided to release the source codes free of charge with the hope that the S-FEM technique 
% can be applied to more problems and can be further developed into even more powerful methods. 
% The authors are not be able to provide any services or user-guides, but appreciate very much your feedback on errors and suggestions, 
% so that we can improve these codes/methods in the future. If the idea, method, and any part of these codes are used in anyway,
% the users are required to cite the book and the following related original papers of the authors:

% Liu GR, The Finite element method  a practical course, Elsevier (BH), UK.  2003.
% Liu, G. R. and Nguyen Thoi Trung, Smoothed Finite Element Method, CRC press, Boca Raton, USA, 2010.
%--------------------------------------------------------------------------

shapeT3(1)=1-psi-eta;
shapeT3(2)=psi;
shapeT3(3)=eta;
% derivatives
dhdrT3(1)=-1;     dhdsT3(1)=-1;
dhdrT3(2)=1;      dhdsT3(2)=0;
dhdrT3(3)=0;      dhdsT3(3)=1;

    