function [shapeT6,dhdrT6,dhdsT6]=get_shape_T6(psi,eta)

%------------------------------------------------------------------------
%  Purpose:
%     compute isoparametric 6-node triangular shape functions
%     and their derivatves at the selected (integration) point
%     in terms of the natural coordinate 
%
%  Synopsis:
%     [shapeT6,dhdrT6,dhdsT6]=feisotri(psi,eta)  
%
%  Variable Description:
%     shapeT6 - shape functions for 6-node triangular element
%     dhdrT6 - derivatives of the shape functions w.r.t. r
%     dhdsT6 - derivatives of the shape functions w.r.t. s
%     psi - r coordinate value of the selected point   
%     eta - s coordinate value of the selected point
%------------------------------------------------------------------------
% 1st node at (0,0), 2nd node at (1,0), 3rd node at (0,1)
% 4th node at (0.5,0), 5th node at (0.5,0.5), 3rd node at (0,0.5)
% shape functions
%--------------------------------------------------------------------------
% Coded by Dr. Nguyen Thoi Trung (Nguyen-Thoi T or Nguyen T.T)            %
% University of Science - Vietnam National University  HCMC, Vietnam     %
% National University of Singapore (NUS)                                  %
% email: thoitrung76@gmail.com                                            %
% Last modified: December 2009                                            %
%--------------------------------------------------------------------------

% Important note: The authors decided to release the source codes free of charge with the hope that the S-FEM technique 
% can be applied to more problems and can be further developed into even more powerful methods. 
% The authors are not be able to provide any services or user-guides, but appreciate very much your feedback on errors and suggestions, 
% so that we can improve these codes/methods in the future. If the idea, method, and any part of these codes are used in anyway,
% the users are required to cite the book and the following related original papers of the authors:

% Liu GR, The Finite element method  a practical course, Elsevier (BH), UK.  2003.
% Liu, G. R. and Nguyen Thoi Trung, Smoothed Finite Element Method, CRC press, Boca Raton, USA, 2010.
%--------------------------------------------------------------------------

shapeT6(1)=(1-psi-eta)*(1-2*psi-2*eta);
shapeT6(2)=psi*(2*psi-1);
shapeT6(3)=eta*(2*eta-1);
shapeT6(4)=4*psi*(1-psi-eta);
shapeT6(5)=4*psi*eta;
shapeT6(6)=4*eta*(1-psi-eta);
%derivatives
dhdrT6(1)=-3+4*psi+4*eta;     dhdsT6(1)=-3+4*psi+4*eta;;
dhdrT6(2)=4*psi-1;            dhdsT6(2)=0;
dhdrT6(3)=0;                  dhdsT6(3)=4*eta-1;
dhdrT6(4)=4-8*psi-4*eta;      dhdsT6(4)=-4*psi;
dhdrT6(5)=4*eta;              dhdsT6(5)=4*psi;
dhdrT6(6)=-4*eta;             dhdsT6(6)=4-4*psi-8*eta;
    