function output_disp_line_2D(disp)

%------------------------------------------------------------------------
%  Purpose:
%     Plot the results of displacement along the chosen line
%
%  Synopsis:
%     output_disp_line_2D(disp)
%
%  Variable Description:
%   disp       = system nodal displacement vector
%--------------------------------------------------------------------------
% Coded by Dr. Nguyen Thoi Trung (Nguyen-Thoi T or Nguyen T.T)            %
% University of Science - Vietnam National University  HCMC, Vietnam     %
% National University of Singapore (NUS) (2005-2010)                      %
% email: thoitrung76@gmail.com                                            %
% Last modified: December 2009                                            %
%--------------------------------------------------------------------------

global sdof ndof nnode gcoord example

switch example
    case 'cantilever'
        global nx ny lengthx
        disp0=zeros(sdof,1);
        for i=1:nnode
            [pdisp0,stress0]=anal_solu_2D(gcoord(i,1),gcoord(i,2));
            disp0(2*i-1)=pdisp0(1,1);
            disp0(2*i)=pdisp0(2,1);
        end

        num=0:1:nx;
        dd=disp(num*(ny+1)*ndof+(ny/2+1)*ndof);
        dd0=disp0(num*(ny+1)*ndof+(ny/2+1)*ndof);
        tip_dd=dd(nx+1); tip_dd0=dd0(nx+1);

        dx=lengthx/nx;          % the length of side of 1 element in x-axis
        xx=num*dx;

        % figure
        % plot(xx,dd0,xx,dd,'r--+');
        % xlabel('x(y=0)');
        % ylabel('Deflection')

        figure
        hold on
        plot(xx,dd0-dd,'m--');
        xlabel('x(y=0)');
        ylabel('Relative error in deflection v0-v ')
        
    case 'platehole'
        global nx ny
        rtdof=nx*(ny+1)*ndof;
        xpu=gcoord(nnode:-1:rtdof/ndof+1,1);  % main coordinates
        % ypu=zeros(length(xpu));
        du=disp(sdof-1:-2:rtdof+1);
        ypv=gcoord(1:ny+1,2);                 % main coordinates
        % xpv=zeros(length(ypv));
        dv=disp(2:2:2*ny+2);
        nn=1;
        for i=1:length(xpu)
            x0=xpu(i); y0=0;    
            [disp0,stress0]=anal_solu_2D(x0,y0);    
            du0(nn)=disp0(1);
            nn=nn+1;
        end

        nn=1;
        for i=1:length(ypv)
            x0=0; y0=ypv(i);    
            [disp0,stress0]=anal_solu_2D(x0,y0);    
            dv0(nn)=disp0(2);
            nn=nn+1;
        end

        figure
        hold on
        subplot(2,1,1)
        plot(xpu,du,'rO',xpu,du0,'b-');
        xlabel('y(x=0)');h = get(gca,'Xlabel');
        set(h,'FontSize',11); set(h,'FontName','Times New Roman');
        ylabel('Displacement u');h = get(gca,'Ylabel');
        set(h,'FontSize',11); set(h,'FontName','Times New Roman');

        hold on
        subplot(2,1,2)
        plot(ypv,dv,'rO',ypv,dv0,'b-'); 
        hold on
        xlabel('x(y=0)');h = get(gca,'Xlabel');
        set(h,'FontSize',11); set(h,'FontName','Times New Roman');
        ylabel('Displacement v');h = get(gca,'Ylabel');
        set(h,'FontSize',11); set(h,'FontName','Times New Roman');    
end
