function output_stress_line_2D(stress_nod)

%------------------------------------------------------------------------
%  Purpose:
%     Plot the results of stress along lines
%
%  Synopsis:
%     output_stress_line_2D(stress_nod)
%
%  Variable Description:
%   stress_nod = matrix containing stresses of nodes
%--------------------------------------------------------------------------
% Coded by Dr. Nguyen Thoi Trung (Nguyen-Thoi T or Nguyen T.T)            %
% University of Science - Vietnam National University  HCMC, Vietnam     %
% National University of Singapore (NUS) (2005-2010)                      %
% email: thoitrung76@gmail.com                                            %
% Last modified: December 2009                                            %
%--------------------------------------------------------------------------

global nnode gcoord example

switch example
    case 'cantilever'
        global nx ny lengthx
        in=0;
        for ino=1:nnode
            if gcoord(ino,1)==lengthx/2
                in=in+1;
                yp(in)=gcoord(ino,2); 
                sxx(in)=stress_nod(1,ino);       
                syy(in)=stress_nod(2,ino);       
                sxy(in)=stress_nod(3,ino);
                [disp0,stress0]=anal_solu_2D(gcoord(ino,1),yp(in));
                sxx0(in)=stress0(1);     
                syy0(in)=stress0(2);     
                sxy0(in)=stress0(3); 
            end
        end

        figure
        subplot(2,1,1)
        hold on
        plot(yp,sxx,'rO',yp,sxx0,'b-')
        %plot(yp,sxx,'ro')
        %plot(yp,sxx0-sxx,'k--')
        xlabel('y(x=L/2)');
        ylabel('Normal stress \sigma_{xx}')

        subplot(2,1,2)
        hold on
        plot(yp,sxy,'rO',yp,sxy0,'b-')
        %plot(yp,sxy,'ro')
        %plot(yp,sxy0-sxy,'k--')
        xlabel('y(x=L/2)');
        ylabel('Shear stress \sigma_{xy}')

        clear sxx syy sxy sxx0 syy0 sxy0

    case 'platehole'
        global nx ny ndof
        rtdof=nx*(ny+1)*ndof;
        xpu=gcoord(nnode:-1:rtdof/ndof+1,1);  % main coordinates
        % ypu=zeros(length(xpu));
        nn=1;
        for i=nnode:-1:rtdof/ndof+1        %rtdof/ndof+1 = nx*(ny+1) + 1 = nnode-ny
            syy(nn)=stress_nod(2,i);
            nn=nn+1;
        end   
        ypv=gcoord(1:ny+1,2);                  % main coordinates
        % xpv=zeros(length(ypv));
        nn=1;
        for i=1:ny+1
            sxx(nn)=stress_nod(1,i);
            nn=nn+1;
        end
        nn=1;
        for i=1:length(xpu)
            x0=xpu(i); y0=0;    
            [disp0,stress0]=anal_solu_2D(x0,y0);    
            syy0(nn)=stress0(2);
            nn=nn+1;
        end

        nn=1;
        for i=1:length(ypv)
            x0=0; y0=ypv(i);    
            [disp0,stress0]=anal_solu_2D(x0,y0);    
            sxx0(nn)=stress0(1);
            nn=nn+1;
        end

        figure
        hold on
        subplot(2,1,1)
        plot(ypv,sxx,'rO',ypv,sxx0,'b-');
        hold on
        xlabel('y(x=0)');h = get(gca,'Xlabel');
        set(h,'FontSize',11); set(h,'FontName','Times New Roman');
        ylabel('Stress \sigma_{xx}');h = get(gca,'Ylabel');
        set(h,'FontSize',11); set(h,'FontName','Times New Roman');

        hold on
        subplot(2,1,2)
        plot(xpu,syy,'rO',xpu,syy0,'b-'); 
        hold on
        xlabel('x(y=0)');h = get(gca,'Xlabel');
        set(h,'FontSize',11); set(h,'FontName','Times New Roman');
        ylabel('Stress \sigma_{yy}');h = get(gca,'Ylabel');
        set(h,'FontSize',11); set(h,'FontName','Times New Roman');   
end